# 171128 Fusion primer optimisation

setwd("~/Documents/UNI_und_VORLESUNGEN/14 Guelph/1 Fusion primer plates/R script")

data <- read.csv("Primers_v1.txt", sep="\t", stringsAsFactors=F)


# Filling primers up semi randomly

temp <- NULL

for (i in 1:nrow(data)){
temp <- rbind(temp, unlist(strsplit(data$Tag[i], "")))
}


# nucleotide table
upac <- read.csv(text=c("ID,comment,A,T,C,G, comp
A,Adenine,1,0,0,0,T
C,Cytosine,0,0,1,0,G
G,Guanine,0,0,0,1,C
T,Thymine,0,1,0,0,A
R,A or G,0.5,0,0,0.5,Y
Y,C or T,0,0.5,0.5,0,R
S,G or C,0,0,0.5,0.5,S
W,A or T,0.5,0.5,0,0,W
K,G or T,0,0.5,0,0.5,M
M,A or C,0.5,0,0.5,0,K
B,C or G or T,0,0.3,0.3,0.3,V
D,A or G or T,0.3,0.3,0,0.3,H
H,A or C or T,0.3,0.3,0.3,0,D
V,A or C or G,0.3,0,0.3,0.3,B
N,any base,0.25,0.25,0.25,0.25,N
I,inosine,0.25,0.25,0.25,0.25,N
-,gap,0,0,0,0,-"), stringsAsFactors=F)

upac[upac==0.3] <- 1/3

comp <- NULL 

for(i in 1:ncol(temp)){
meep <- colSums(upac[match(temp[,i], upac$ID), 3:6], na.rm=T)
comp <- rbind(comp, meep)
}

pdf("Primer_bases.pdf")
x <- barplot(t(comp), col=c("Red", "lawngreen", "Yellow", "dodgerblue"), names=1:7, main="Primer base composition")

text(x, colSums(t(comp)[1:3,])+t(comp)[4,]/2, round(t(comp)[4,]))
text(x, colSums(t(comp)[1:2,])+t(comp)[3,]/2, round(t(comp)[3,]))
text(x, t(comp)[1,]+t(comp)[2,]/2, round(t(comp)[2,]))
text(x, t(comp)[1,]/2, round(t(comp)[1,]))


dev.off()


# run X itterations

for (g in 1:10){
temp2 <- temp
# fill bases that are numeric with proportionately random numbers

for (i in 1:ncol(temp2)){
replace <- suppressWarnings(!is.na(as.numeric(temp2[,i], warn=F)))

sampleset <- NULL
for (m in 1:4){
abund_nuc <- 6-round(comp[i,m])
if (abund_nuc < 0){abund_nuc<- 0}
sampleset <- c(sampleset, rep(c("A", "T", "C", "G")[m], abund_nuc))
}

temp2[,i][replace] <- sample(sampleset)[1:sum(replace)]

}


# plot bases
tempCol <- temp2

tempCol[tempCol =="A"] <- "Red"
tempCol[tempCol =="T"] <- "lawngreen"
tempCol[tempCol =="G"] <- "Yellow"
tempCol[tempCol =="C"] <- "dodgerblue"
tempCol[nchar(tempCol)==1] <- "lightgray"

pdf(paste("1_Primer_plots/", g,"_alignment.pdf", sep=""), height= 7, width=4)

plot(NULL, ylim=c(nrow(temp2), 1), xlim=c(-2,ncol(temp)+0.5), ylab="", yaxt="n", xaxt="n", xlab="")
axis(1, at=1:nrow(temp2))
text(0.3, 1:nrow(temp2),  data$ID, adj=1)

for (m in 1:ncol(temp2)){

for (j in 1:nrow(temp2)){
if(data$rm[j]>=m){border <- "black"} else {border <- F}
rect(m-0.48, j-0.46, m+0.48, j+0.46, col= tempCol[j,m], border= border, lwd=1.5, )
text(m, j, temp2[j,m])
}

}
dev.off()

#save tags

merge <- NULL
tag_only <- NULL

for (n in 1:nrow(temp2)){
merge[n] <- paste(temp2[n,], collapse="")
tag_only[n] <- paste(temp2[n,1:data$rm[n]], collapse="")
}

exp <- data.frame("ID"=data$ID, "rm"=data$rm, merge, tag_only)

write.csv(exp, file=paste("1_Primer_plots/", g,"_tags_tab.csv", sep=""), row.names=F)



}






